@@ -1752,7 +1752,10 @@ class SimpleClassifier(nn.Module):
 
 tokenizer = BertTokenizer.from_pretrained("bert-base-uncased", do_lower_case=True)
 
+
 class VilBERT(VILBertForVLTasks):
+    max_length = None
+    
     def forward(
         self,   
         batch    
@@ -1777,7 +1780,7 @@ class VilBERT(VILBertForVLTasks):
                 input_mask += padding
                 segment_ids += padding
 
-            assert_eq(len(tokens), max_length)
+            assert len(tokens)== max_length
             entry["q_token"] = tokens
             entry["q_input_mask"] = input_mask
             entry["q_segment_ids"] = segment_ids
