@@ -2,6 +2,7 @@ from pySmartDL import SmartDL
 import os
 from shutil import unpack_archive
 
+
 def get_basename(url):
     return url.split("/")[-1]
 
@@ -25,3 +26,15 @@ def download_and_unzip(url, directory=None, filename=None, path=None):
         directory = os.path.basename(path)
     dest = download_file(url, directory, filename=filename)
     unpack_archive(dest, extract_dir=directory)
+
+
+class Task:
+    def __init__(self, path, name):
+        self.path = os.path.join(path, name + ".done")
+
+    def is_done(self):
+        return os.path.exists(self.path)
+
+    def mark_done(self):
+        open(self.path, "a").close()
+
